# 0.6
- Restart from scratch
- Use pyramid-authsanity
- Restore Google
- Restore encryption

# 0.5
- Add user.name, user.image_url
- Replace velruse with requests-oauthlib
- Support Google, LinkedIn
- Use pyramid-multiauth

# 0.4
- Define request.authenticated_user
- Remove user.token

# 0.3
- Add UserFolderMixin
- Include CSRF token for PATCH requests

# 0.2
- Let downstream packages override User, RootFactory

# 0.1
- Add pyramid_redis_sessions
